@@ -156,7 +156,9 @@ def main(argv=None):
                 notifications,
                 sent_notifications,
                 finished,
-                config['email']
+                config['email'],
+                config['webhook'],
+                config['pagerduty']
             ).run),
         )
     processors.extend(notification_processors)
